"""
    module FACT_data_API_reader

A Julia module for retrieving various types of data including geographic objects, travel time information, job and population statistics, airport traffic data, elevation data, rail station and line data, port tonnage data, power station and transmission line data, land use data, geology and mineral data, and building footprint and height data.

## Exported Functions
- `get_geo_objects`: Retrieves geographic objects from the FACT_geo database on Port 3307.
- `get_travel_data_eu`: Retrieves travel time data for European Union (EU) geographic locations using a service query and a specified host and port.
- `get_travel_data_na`: Retrieves travel time data for North America (NA) geographic locations using a service query and a specified host and port.
- `get_annual_jobs`: Retrieves annual job data from the FACT_jobs database on Port 3308.
- `get_annual_population`: Retrieves annual population data from the FACT_population database on Port 3309.
- `get_airports_traffic`: Retrieves airports traffic data from the FACT_air database on Port 3310.
- `get_elevation_data`: Retrieves elevation data using an HTTP request to the specified host and port.
- `get_rail_stations_lines`: Retrieves data related to rail stations and lines from the FACT_rail database on Port 3311.
- `get_ports_tonnage`: Retrieves data related to ports and tonnage from the FACT_ports database on Port 3312.
- `get_power_stations_lines`: Retrieves data related to power stations and transmission lines from the FACT_power database on Port 3313.
- `get_land_use_data`: Retrieves land use data using an HTTP request to the specified host and port.
- `get_geology`: Retrieves geology data from the FACT_mine database on Port 3314.
- `get_minerals`: Retrieves mineral data from the FACT_mine database on Port 3314.
- `get_bldgs_footprint_height`: Retrieves building footprint and height data from the FACT_bldgs database on Port 3315.

The module is designed to help with data retrieval and analysis for various domains.

"""
module FACT_data_API_reader

    using DataFrames, MySQL, Tables, LibGEOS, HTTP, JSON

    include("utils_DB_connection.jl")
    include("utils_DB_query.jl")
    include("utils_web_service.jl")
    include("utils_containers_configuration.jl")
    export get_data_container_config
    include("FACT_geo.jl")
    export get_geo_objects
    include("FACT_road.jl")
    export get_travel_data_eu, get_travel_data_na
    include("FACT_jobs.jl")
    export get_annual_jobs
    include("FACT_population.jl")
    export get_annual_population
    include("FACT_air.jl")
    export get_airports_traffic
    include("FACT_elevation.jl")
    export get_elevation_data
    include("FACT_rail.jl")
    export get_rail_stations_lines
    include("FACT_ports.jl")
    export get_ports_tonnage
    include("FACT_power.jl")
    export get_power_stations_lines
    include("FACT_lulc.jl")
    export get_land_use_data
    include("FACT_mine.jl")
    export get_geology, get_minerals
    include("FACT_bldgs.jl")
    export get_bldgs_footprint_height


end # module FACT_data_API_reader
